GoogleSearch_services

|  | ## Cheshire3: GoogleSearch_services Module

Module GoogleSearch_services

Classes | [hide private]
GoogleSearchServiceInterface |
GoogleSearchServiceLocator |
GoogleSearchBindingSOAP |
doGetCachedPage |
doGetCachedPageWrapper | wrapper for rpc:encoded message
doGetCachedPageResponse |
doGetCachedPageResponseWrapper | wrapper for rpc:encoded message
doGoogleSearch |
doGoogleSearchWrapper | wrapper for rpc:encoded message
doGoogleSearchResponse |
doGoogleSearchResponseWrapper | wrapper for rpc:encoded message
doSpellingSuggestion |
doSpellingSuggestionWrapper | wrapper for rpc:encoded message
doSpellingSuggestionResponse |
doSpellingSuggestionResponseWrapper | wrapper for rpc:encoded message